aboutsummaryrefslogtreecommitdiffstats
path: root/arch/x86/kernel/genx2apic_uv_x.c
diff options
context:
space:
mode:
authorMike Travis <travis@sgi.com>2008-10-27 07:51:20 -0700
committerIngo Molnar <mingo@elte.hu>2008-10-27 19:50:42 +0100
commit69a72a0e9337aad8c730e8e9942d5aa022bc4c5c (patch)
treeda298e9cf425ec667132a02270de7807aa32a483 /arch/x86/kernel/genx2apic_uv_x.c
parentx86/uv: provide a System Activity Indicator driver (diff)
downloadlinux-dev-69a72a0e9337aad8c730e8e9942d5aa022bc4c5c.tar.xz
linux-dev-69a72a0e9337aad8c730e8e9942d5aa022bc4c5c.zip
x86/uv: update SCIR driver to use the idle_cpu() function
Impact: cleanup Change UV heartbeat function to use idle_cpu to determine cpu's "idleness". Realign uv_hub definitions. Signed-of-by: Mike Travis <travis@sgi.com> Signed-off-by: Ingo Molnar <mingo@elte.hu>
Diffstat (limited to 'arch/x86/kernel/genx2apic_uv_x.c')
-rw-r--r--arch/x86/kernel/genx2apic_uv_x.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/arch/x86/kernel/genx2apic_uv_x.c b/arch/x86/kernel/genx2apic_uv_x.c
index 84367d84bb10..85fb7dd48f67 100644
--- a/arch/x86/kernel/genx2apic_uv_x.c
+++ b/arch/x86/kernel/genx2apic_uv_x.c
@@ -370,8 +370,8 @@ static void uv_heartbeat(unsigned long ignored)
/* flip heartbeat bit */
bits ^= SCIR_CPU_HEARTBEAT;
- /* are we the idle thread? */
- if (current->pid == 0)
+ /* is this cpu idle? */
+ if (idle_cpu(raw_smp_processor_id()))
bits &= ~SCIR_CPU_ACTIVITY;
else
bits |= SCIR_CPU_ACTIVITY;